@@ -23,10 +23,12 @@
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QQuickStyle>
 
 // Frameworks
 #include <KAboutData>
-#include <KLocalizedContext>
+#include <KCrash>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 #include <KPluginMetaData>
 
@@ -35,21 +37,28 @@ using namespace Qt::Literals::StringLiterals;
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
 
-    KLocalizedString::setApplicationDomain("mobile.plasma-settings");
+    KLocalizedString::setApplicationDomain("mobile.plasmasettings");
 
     // About data
-    KAboutData aboutData(u"org.kde.mobile.plasmasettings"_s,
+    KAboutData aboutData(u"plasma-settings"_s,
                          i18n("Settings"),
                          QStringLiteral(PLASMA_SETTINGS_VERSION_STRING),
                          i18n("Touch-friendly settings application."),
                          KAboutLicense::GPL,
-                         i18n("Copyright 2011-2015, Sebastian Kügler"));
-    aboutData.addAuthor(i18n("Sebastian Kügler"), i18n("Maintainer"), u"sebas@kde.org"_s);
-    aboutData.addAuthor(i18n("Marco Martin"), i18n("Maintainer"), u"mart@kde.org"_s);
+                         i18n("© 2011-2015 KDE Community"));
+    aboutData.addAuthor(i18n("Devin Lin"), i18n("Maintainer"), u"espidev@gmail.com"_s);
+    aboutData.addAuthor(i18n("Sebastian Kügler"), i18n("Previous Maintainer"), u"sebas@kde.org"_s);
+    aboutData.addAuthor(i18n("Marco Martin"), i18n("Previous Maintainer"), u"mart@kde.org"_s);
     aboutData.setDesktopFileName(u"org.kde.mobile.plasmasettings"_s);
     KAboutData::setApplicationData(aboutData);
 
+    KCrash::initialize();
+
     QApplication::setWindowIcon(QIcon::fromTheme(u"preferences-system"_s));
 
     QCommandLineParser parser;
@@ -76,14 +85,19 @@ int main(int argc, char **argv)
     aboutData.processCommandLine(&parser);
 
     if (parser.isSet(listOption)) {
-        int nameWidth = 24;
         QSet<QString> seen;
         std::cout << std::setfill('.');
 
-        auto formfactor = parser.value(formfactorOption);
+        const auto formfactor = parser.value(formfactorOption);
 
         const auto plugins = KPluginMetaData::findPlugins(u"kcms"_s)
             << KPluginMetaData::findPlugins(u"plasma/kcms"_s) << KPluginMetaData::findPlugins(u"plasma/kcms/systemsettings"_s);
+
+        const auto longest = std::ranges::max_element(plugins, [](const auto &left, const auto &right) {
+            return left.pluginId().length() < right.pluginId().length();
+        });
+        const int nameWidth = longest->pluginId().length();
+
         for (const auto &plugin : plugins) {
             if (seen.contains(plugin.pluginId())) {
                 continue;
@@ -93,11 +107,6 @@ int main(int argc, char **argv)
             if (!formfactor.isEmpty() && !plugin.formFactors().contains(formfactor) && formfactor != QStringLiteral("all")) {
                 continue;
             }
-            const int len = plugin.pluginId().length();
-            if (len > nameWidth) {
-                nameWidth = len;
-            }
-
             seen << plugin.pluginId();
             std::cout << plugin.pluginId().toLocal8Bit().data() << ' ' << std::setw(nameWidth - plugin.pluginId().length() + 2) << '.' << ' '
                       << plugin.description().toLocal8Bit().data() << std::endl;
@@ -105,23 +114,6 @@ int main(int argc, char **argv)
             // qDebug() << "Formafactors: " << formFactors;
         }
 
-        const auto kcmPlugin = KPluginMetaData::findPlugins(u"kcms"_s)
-            << KPluginMetaData::findPlugins(u"plasma/kcms"_s) << KPluginMetaData::findPlugins(u"plasma/kcms/systemsettings"_s);
-        for (const auto &plugin : kcmPlugin) {
-            if (seen.contains(plugin.pluginId())) {
-                continue;
-            }
-            if (!formfactor.isEmpty() && !plugin.formFactors().contains(formfactor) && formfactor != QStringLiteral("all")) {
-                continue;
-            }
-            const int len = plugin.pluginId().length();
-            if (len > nameWidth) {
-                nameWidth = len;
-            }
-            std::cout << plugin.pluginId().toLocal8Bit().data() << ' ' << std::setw(nameWidth - plugin.pluginId().length() + 2) << '.' << ' '
-                      << plugin.description().toLocal8Bit().data() << std::endl;
-        }
-
         return 0;
     }
 
@@ -133,17 +125,13 @@ int main(int argc, char **argv)
         return 0;
     }
 
-    auto *settingsApp = new SettingsApp(parser);
-    settingsApp->setStartModule(module);
-    settingsApp->setSingleModule(singleModule);
-
-    qmlRegisterType<ModulesProxyModel>("org.kde.plasma.settings", 0, 1, "ModulesProxyModel");
-    qmlRegisterType<Module>("org.kde.plasma.settings", 0, 1, "Module");
-    qmlRegisterSingletonInstance<SettingsApp>("org.kde.plasma.settings", 0, 1, "SettingsApp", settingsApp);
-
     QQmlApplicationEngine engine;
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
+    KLocalization::setupLocalizedContext(&engine);
+    const auto settingsApp = engine.singletonInstance<SettingsApp *>("org.kde.plasma.settings", "SettingsApp");
+    settingsApp->init(parser, module, singleModule);
+    engine.loadFromModule("org.kde.plasma.settings", "Main");
+
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.mobile.plasmasettings")));
 
     return app.exec();
 }
